abacusai.model_upload — AbacusAI documentation

# `abacusai.model_upload`

## Module Contents

### Classes

`ModelUpload` | A Model Version that includes the upload ids for the various required files.

class abacusai.model_upload.ModelUpload(client, modelId=None, modelVersion=None, status=None, createdAt=None, modelUploadId=None, embeddingsUploadId=None, artifactsUploadId=None, verificationsUploadId=None, defaultItemsUploadId=None, modelFileUploadId=None, modelStateUploadId=None, inputPreprocessorUploadId=None, requirementsUploadId=None, resourcesUploadId=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A Model Version that includes the upload ids for the various required files.

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - modelId (str) – A reference to the model this version belongs to

    - modelVersion (str) – The unique identifier of a model version.

    - status (str) – The current status of the model.

    - createdAt (str) – The timestamp at which the model version was created.

    - modelUploadId (str) – An Upload Identifier to be used when uploading the Tensorflow Saved Model

    - embeddingsUploadId (str) – An Upload Identifier to be used when uploading the embeddings csv

    - artifactsUploadId (str) – An Upload Identifier to be used when uploading the artifacts json file

    - verificationsUploadId (str) – An Upload Identifier to be used when uploading the verifications json file

    - defaultItemsUploadId (str) – An Upload Identifier to be used when uploading the default items json file

    - modelFileUploadId (str) – An Upload Identifier to be used when uploading the model json file

    - modelStateUploadId (str) – An Upload Identifier to be used when uploading the model state json file

    - inputPreprocessorUploadId (str) – An Upload Identifier to be used when uploading the input preprocessor json file

    - requirementsUploadId (str) – An Upload Identifier to be used when uploading the requirements json file

    - resourcesUploadId (str) – An Upload Identifier to be used when uploading the resources json file

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict